# coffee-roulette
coffee_roulette is a pseudo-random pair generator. It ensures unique pairings among the subjects in each round and optionally suggests a conversation starter and meeting time. 

The code was written for the Coffee Roulette initiative organised by the Research Culture Working Group, Community subgroup, at the Sainsbury Wellcome Centre between January 2021 and November 2022. 
